# -*- encoding: utf-8 -*-
"""
@File    :   __init__.py.py    
@Contact :   qiull@tellhow.com
@Author  :   Long-Long-Qiu
@Modify Time      @Version    @Description
------------      --------    -----------
2024/12/16 14:01                None
"""
